@@ -1,5 +1,5 @@
 #!/bin/bash
-#  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+#  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -16,15 +16,8 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-# This script deletes IP alias(es) inside VE for Debian like distros.
-# For usage info see ve-alias_del(5) man page.
-#
-# Parameters are passed in environment variables.
-# Required parameters:
-#   IP_ADDR       - IPs to delete, several addresses should be divided by space
-# Optional parameters:
-#   VE_STATE      - state of VE; could be one of:
-#                     starting | stopping | running | stopped
+# Deletes IP address(es) from a container running Debian-like distros.
+
 VENET_DEV=venet0
 CFGFILE=/etc/network/interfaces
 
@@ -37,7 +30,7 @@ function del_ip()
 	for ip in ${IP_ADDR}; do
 		if [ "${ip#*:}" = "${ip}" ]; then
 
-		    ifname=`grep -B 1 -w "${ip}" ${CFGFILE} | \
+		    ifname=`grep -B 1 -w "${ip}" ${CFGFILE} |
 				grep "${VENET_DEV}:" | cut -d' ' -f2`
 		    if [ -n "${ifname}" ]; then
 				ifdown "${ifname}" 2>/dev/null
@@ -45,9 +38,9 @@ function del_ip()
 		    fi
 
 		else
-		    grep -v ${ip} /etc/network/interfaces > ${CFGFILE}.bak
+		    grep -v ${ip} ${CFGFILE} > ${CFGFILE}.bak
+		    ifconfig ${VENET_DEV} del ${ip}/0
 		    mv ${CFGFILE}.bak ${CFGFILE}
-		    /etc/init.d/networking restart > /dev/null 2>&1
 		fi
 	done
 }
